---
id: 103
properties:
- id: priority
  name: testy
  type: string
  value: High
- id: done
  name: Done
  type: boolean
  value: false
- id: status
  name: Status
  type: status
  value: Not Started
---

Just do stuff